# Generated by roxygen2: do not edit by hand

S3method(plot,RandomField)
export(GMD)
export(Mu)
export(autocov)
export(bandwidth)
export(block_pValue)
export(block_stat)
export(block_test)
export(changeRegion)
export(crit.grubbs)
export(decorr)
export(genField)
export(genTheta)
export(grubbs)
export(kurtosis)
export(rmix)
export(sOpt)
export(sSizes)
export(skewness)
import(Rcpp)
import(stats)
importFrom(Rcpp,evalCpp)
importFrom(expm,sqrtm)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guides)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(grDevices,rgb)
importFrom(methods,is)
importFrom(nortest,ad.test)
importFrom(nortest,lillie.test)
importFrom(robcp,modifChol)
useDynLib(SChangeBlock)
